pub fn parse_routing_host_from_headers(
headers: &HeaderMap,
) -> Option<RoutingHost>Expand description
Pull the Host header and parse it with parse_routing_host.
pub fn parse_routing_host_from_headers(
headers: &HeaderMap,
) -> Option<RoutingHost>Pull the Host header and parse it with parse_routing_host.