pub fn required_param(
params: &HashMap<String, String>,
name: &str,
) -> Result<String, AwsServiceError>Expand description
Extract a required parameter from a query parameter map.
Returns MissingParameter error if the parameter is missing or empty.