pub struct DeliveryBus { /* private fields */ }Expand description
Cross-service message delivery.
Services use this to deliver messages to other services without direct dependencies between service crates. The server wires up the delivery functions at startup.
Implementations
Sourceimpl DeliveryBus
impl DeliveryBus
pub fn new() -> Self
pub fn with_sqs(self, sender: Arc<dyn SqsDelivery>) -> Self
pub fn with_sns(self, sender: Arc<dyn SnsDelivery>) -> Self
Sourcepub fn send_to_sqs(
&self,
queue_arn: &str,
message_body: &str,
attributes: &HashMap<String, String>,
)
pub fn send_to_sqs( &self, queue_arn: &str, message_body: &str, attributes: &HashMap<String, String>, )
Send a message to an SQS queue identified by ARN.